@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 # pylint: disable=line-too-long
 """`tensorflow_datasets` (`tfds`) defines a collection of datasets ready-to-use with TensorFlow.
 
@@ -34,37 +33,22 @@ Documentation:
 * [Colab tutorial](https://colab.research.google.com/github/tensorflow/datasets/blob/master/docs/overview.ipynb)
 * [Add a dataset](https://www.tensorflow.org/datasets/add_dataset)
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
-# pylint: enable=line-too-long
-# pylint: disable=g-import-not-at-top,g-bad-import-order,wrong-import-position
+import sys
 
-# Ensure TensorFlow is importable and its version is sufficiently recent. This
-# needs to happen before anything else, since the imports below will try to
-# import tensorflow, too.
-from tensorflow_datasets.core import tf_compat
-tf_compat.ensure_tf_install()
-
-# Imports for registration
 # pylint: disable=g-import-not-at-top
-from tensorflow_datasets import audio
-from tensorflow_datasets import image
-from tensorflow_datasets import image_classification
-from tensorflow_datasets import object_detection
-from tensorflow_datasets import question_answering
-from tensorflow_datasets import structured
-from tensorflow_datasets import summarization
-from tensorflow_datasets import text
-from tensorflow_datasets import translate
-from tensorflow_datasets import video
 
+# TODO(py2): Cleanup once Py2 support is dropped entirely
+if sys.version_info[0] < 3:
+  print("""
+  ************************************************
+  *   WARNING: TFDS IS UNSUPORTED FOR PYTHON 2   *
+  ************************************************
+  """)
+  from tensorflow_datasets import __init__py2 as api
+  from tensorflow_datasets.__init__py2 import *
+else:
+  from tensorflow_datasets import __init__py3 as api
+  from tensorflow_datasets.__init__py3 import *
 
-# Public API to create and generate a dataset
-from tensorflow_datasets.public_api import *  # pylint: disable=wildcard-import
-
-# __all__ for import * as well as documentation
-from tensorflow_datasets import public_api  # pylint: disable=g-bad-import-order
-__all__ = public_api.__all__
-
+__all__ = api.__all__
