@@ -13,20 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Base decoders.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import abc
 import functools
 
 import six
 import tensorflow.compat.v2 as tf
-from tensorflow_datasets.core import api_utils
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -55,8 +49,7 @@ class Decoder(object):
   def __init__(self):
     self.feature = None
 
-  @api_utils.disallow_positional_args
-  def setup(self, feature):
+  def setup(self, *, feature):
     """Transformation contructor.
 
     The initialization of decode object is deferred because the objects only
