@@ -13,15 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Methods to retrieve and store size/checksums associated to URLs.
 
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 from typing import Any, Dict, Iterable, List
 
@@ -145,22 +140,30 @@ def _get_url_infos(checksums_path: str) -> Dict[str, UrlInfo]:
   """Returns {URL: (size, checksum)}s stored within file at given path."""
   with tf.io.gfile.GFile(checksums_path) as f:
     content = f.read()
-  return parse_url_infos(content.splitlines())
+  return _parse_url_infos(content.splitlines())
 
 
-def parse_url_infos(checksums_file: Iterable[str]) -> Dict[str, UrlInfo]:
+def _parse_url_infos(checksums_file: Iterable[str]) -> Dict[str, UrlInfo]:
   """Returns {URL: (size, checksum)}s stored within given file."""
   url_infos = {}
   for line in checksums_file:
     line = line.strip()  # Remove the trailing '\r' on Windows OS.
     if not line or line.startswith('#'):
       continue
-    # URL might have spaces inside, but size and checksum will not.
-    url, size, checksum = line.rsplit(' ', 2)
+    try:
+      url, size, checksum = line.split('\t')
+    except ValueError:  # not enough values to unpack (legacy files)
+      # URL might have spaces inside, but size and checksum will not.
+      url, size, checksum = line.rsplit(' ', 2)
     url_infos[url] = UrlInfo(size=int(size), checksum=checksum)
   return url_infos
 
 
+def url_infos_from_path(checksums_path: str) -> Dict[str, UrlInfo]:
+  with tf.io.gfile.GFile(checksums_path) as f:
+    return _parse_url_infos(f.read().splitlines())
+
+
 @utils.memoize()
 def get_all_url_infos() -> Dict[str, UrlInfo]:
   """Returns dict associating URL to (size, sha256)."""
@@ -201,4 +204,4 @@ def store_checksums(dataset_name: str, url_infos: Dict[str, UrlInfo]) -> None:
     return
   with tf.io.gfile.GFile(path, 'w') as f:
     for url, url_info in sorted(new_data.items()):
-      f.write('{} {} {}\n'.format(url, url_info.size, url_info.checksum))
+      f.write('{}\t{}\t{}\n'.format(url, url_info.size, url_info.checksum))
