@@ -13,17 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Download manager interface."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import concurrent.futures
 import hashlib
 import os
-from typing import Optional, Union
+from typing import Dict, Optional, Union
 import uuid
 
 from absl import logging
@@ -31,7 +26,6 @@ import promise
 import six
 import tensorflow.compat.v2 as tf
 
-from tensorflow_datasets.core import api_utils
 from tensorflow_datasets.core import utils
 from tensorflow_datasets.core.download import checksums
 from tensorflow_datasets.core.download import downloader
@@ -111,7 +105,7 @@ class DownloadConfig(object):
     self.download_mode = util.GenerateMode(
         download_mode or util.GenerateMode.REUSE_DATASET_IF_EXISTS)
     self.compute_stats = util.ComputeStatsMode(
-        compute_stats or util.ComputeStatsMode.AUTO)
+        compute_stats or util.ComputeStatsMode.SKIP)
     self.max_examples_per_split = max_examples_per_split
     self.register_checksums = register_checksums
     self.force_checksums_validation = force_checksums_validation
@@ -168,13 +162,14 @@ class DownloadManager(object):
   ...), you can pass a `tfds.download.Resource` as argument.
   """
 
-  @api_utils.disallow_positional_args
   def __init__(
       self,
+      *,
       download_dir: str,
       extract_dir: Optional[str] = None,
       manual_dir: Optional[str] = None,
       manual_dir_instructions: Optional[str] = None,
+      url_infos: Optional[Dict[str, checksums.UrlInfo]] = None,
       dataset_name: Optional[str] = None,
       force_download: bool = False,
       force_extraction: bool = False,
@@ -189,6 +184,7 @@ class DownloadManager(object):
       manual_dir: Path to manually downloaded/extracted data directory.
       manual_dir_instructions: Human readable instructions on how to
         prepare contents of the manual_dir for this dataset.
+      url_infos: Urls info for the checksums.
       dataset_name: Name of dataset this instance will be used for. If
         provided, downloads will contain which datasets they were used for.
       force_download: If True, always [re]download.
@@ -210,8 +206,12 @@ class DownloadManager(object):
     self._force_extraction = force_extraction
     self._force_checksums_validation = force_checksums_validation
     self._register_checksums = register_checksums
-    # All known URLs: {url: (size, checksum)}
+
+    # All known URLs: {url: UrlInfo(size=, checksum=)}
     self._url_infos = checksums.get_all_url_infos()
+    if url_infos is not None:
+      self._url_infos.update(url_infos)
+
     # To record what is being used: {url: (size, checksum)}
     self._recorded_url_infos = {}
     # These attributes are lazy-initialized since they must be cleared when this
@@ -416,8 +416,7 @@ class DownloadManager(object):
   def download_checksums(self, checksums_url):
     """Downloads checksum file from the given URL and adds it to registry."""
     checksums_path = self.download(checksums_url)
-    with tf.io.gfile.GFile(checksums_path) as f:
-      self._url_infos.update(checksums.parse_url_infos(f))
+    self._url_infos.update(checksums.url_infos_from_path(checksums_path))
 
   # Synchronize and memoize decorators ensure same resource will only be
   # processed once, even if passed twice to download_manager.
@@ -631,12 +630,8 @@ def _read_url_info(url_path: str) -> checksums.UrlInfo:
   return checksums.UrlInfo(**file_info['url_info'])
 
 
-def _wait_on_promise(p):
-  return p.get()
-
-
 def _map_promise(map_fn, all_inputs):
   """Map the function into each element and resolve the promise."""
   all_promises = tf.nest.map_structure(map_fn, all_inputs)  # Apply the function
-  res = tf.nest.map_structure(_wait_on_promise, all_promises)
+  res = tf.nest.map_structure(lambda p: p.get(), all_promises)  # Wait promises
   return res
