@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Lazy imports for heavy dependencies."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import importlib
 
 from tensorflow_datasets.core.utils import py_utils as utils
@@ -30,12 +25,12 @@ def _try_import(module_name):
   try:
     mod = importlib.import_module(module_name)
     return mod
-  except ImportError:
+  except ImportError as e:
     err_msg = ("Failed importing {name}. This likely means that the dataset "
                "requires additional dependencies that have to be "
                "manually installed (usually with `pip install {name}`). See "
                "setup.py extras_require.").format(name=module_name)
-    utils.reraise(suffix=err_msg)
+    utils.reraise(e, suffix=err_msg)
 
 
 class LazyImporter(object):
@@ -127,9 +122,17 @@ class LazyImporter(object):
   def skimage(cls):
     _try_import("skimage.color")
     _try_import("skimage.filters")
-    _try_import("skimage.external.tifffile")
+    try:
+      _try_import("skimage.external.tifffile")
+    except ImportError:
+      pass
     return _try_import("skimage")
 
+  @utils.classproperty
+  @classmethod
+  def tifffile(cls):
+    return _try_import("tifffile")
+
   @utils.classproperty
   @classmethod
   def tensorflow_data_validation(cls):
