@@ -13,15 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Tests for tensorflow_datasets.core.lazy_imports."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from absl.testing import parameterized
-import six
 import tensorflow_datasets as tfds
 from tensorflow_datasets import testing
 
@@ -44,18 +38,15 @@ class LazyImportsTest(testing.TestCase, parameterized.TestCase):
       "pydub",
       "scipy",
       "skimage",
+      "tifffile",
       "tldextract",
   )
   def test_import(self, module_name):
-    if module_name == "nltk" and six.PY2:  # sklearn do not support Python2
-      return
-    # TODO(rsepassi): Re-enable skimage on Py3 (b/129964829)
-    if module_name == "skimage" and six.PY3:
-      return
     getattr(tfds.core.lazy_imports, module_name)
 
   def test_bad_import(self):
-    with self.assertRaisesWithPredicateMatch(ImportError, "extras_require"):
+    with self.assertRaisesWithPredicateMatch(
+        ModuleNotFoundError, "extras_require"):
       _ = tfds.core.lazy_imports.test_foo
 
 
