@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """PatchCamelyon images dataset."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import tensorflow_datasets.public_api as tfds
 
 _DESCRIPTION = """\
@@ -46,8 +41,10 @@ _URL = 'https://patchcamelyon.grand-challenge.org/'
 class PatchCamelyon(tfds.core.GeneratorBasedBuilder):
   """PatchCamelyon."""
 
-  VERSION = tfds.core.Version(
-      '2.0.0', 'New split API (https://tensorflow.org/datasets/splits)')
+  VERSION = tfds.core.Version('2.0.0')
+  RELEASE_NOTES = {
+      '2.0.0': 'New split API (https://tensorflow.org/datasets/splits)',
+  }
 
   def _info(self):
     return tfds.core.DatasetInfo(
